package cn.com.infosec.asn1.x509;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERObjectIdentifier;
import cn.com.infosec.asn1.DERSequence;

public class AccessDescription extends ASN1Encodable {
   public static final DERObjectIdentifier id_ad_caIssuers = new DERObjectIdentifier("1.3.6.1.5.5.7.48.2");
   public static final DERObjectIdentifier id_ad_ocsp = new DERObjectIdentifier("1.3.6.1.5.5.7.48.1");
   DERObjectIdentifier accessMethod = null;
   GeneralName accessLocation = null;

   public static AccessDescription getInstance(Object obj) {
      if (obj instanceof AccessDescription) {
         return (AccessDescription)obj;
      } else if (obj instanceof ASN1Sequence) {
         return new AccessDescription((ASN1Sequence)obj);
      } else {
         throw new IllegalArgumentException("unknown object in factory: " + obj.getClass().getName());
      }
   }

   public AccessDescription(ASN1Sequence seq) {
      if (seq.size() == 2) {
         this.accessMethod = DERObjectIdentifier.getInstance(seq.getObjectAt(0));
         this.accessLocation = GeneralName.getInstance(seq.getObjectAt(1));
      } else {
         throw new IllegalArgumentException("wrong number of elements in inner sequence");
      }
   }

   public AccessDescription(DERObjectIdentifier oid, GeneralName location) {
      this.accessMethod = oid;
      this.accessLocation = location;
   }

   public DERObjectIdentifier getAccessMethod() {
      return this.accessMethod;
   }

   public GeneralName getAccessLocation() {
      return this.accessLocation;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      ASN1EncodableVector var10000 = var1 = new ASN1EncodableVector;
      var1.<init>();
      var1.add(this.accessMethod);
      var10000.add(this.accessLocation);
      return new DERSequence(var1);
   }

   public String toString() {
      return "AccessDescription: Oid(" + this.accessMethod.getId() + ")";
   }
}
